@@ -22,6 +22,8 @@ export var CHANGE_CATALOG_PAGE = 'CHANGE_CATALOG_PAGE';
 export var GO_BACK_TO_CATALOG_PAGE = 'GO_BACK_TO_CATALOG_PAGE';
 export var THROW_ERROR = 'THROW_ERROR';
 export var THROW_WARNING = 'THROW_WARNING';
+export var COPY_PROPERTIES = 'COPY_PROPERTIES';
+export var PASTE_PROPERTIES = 'PASTE_PROPERTIES';
 
 // ACTIONS viewer2D
 export var SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -103,7 +105,9 @@ export var PROJECT_ACTIONS = {
   CHANGE_CATALOG_PAGE: CHANGE_CATALOG_PAGE,
   GO_BACK_TO_CATALOG_PAGE: GO_BACK_TO_CATALOG_PAGE,
   THROW_ERROR: THROW_ERROR,
-  THROW_WARNING: THROW_WARNING
+  THROW_WARNING: THROW_WARNING,
+  COPY_PROPERTIES: COPY_PROPERTIES,
+  PASTE_PROPERTIES: PASTE_PROPERTIES
 };
 
 export var VIEWER2D_ACTIONS = {
