@@ -35,5 +35,7 @@ export default {
   "Rotation": "Rotazione",
   "Altitude": "Quota",
   "Name": "Nome",
-  "Would you want to start a new Project?": "Vuoi iniziare un nuovo progetto?"
+  "Would you want to start a new Project?": "Vuoi iniziare un nuovo progetto?",
+  "Copy": "Copia",
+  "Paste": "Incolla"
 };
\ No newline at end of file
