@@ -22,6 +22,8 @@ export const CHANGE_CATALOG_PAGE = 'CHANGE_CATALOG_PAGE';
 export const GO_BACK_TO_CATALOG_PAGE = 'GO_BACK_TO_CATALOG_PAGE';
 export const THROW_ERROR = 'THROW_ERROR';
 export const THROW_WARNING = 'THROW_WARNING';
+export const COPY_PROPERTIES = 'COPY_PROPERTIES';
+export const PASTE_PROPERTIES = 'PASTE_PROPERTIES';
 
 // ACTIONS viewer2D
 export const SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -103,7 +105,9 @@ export const PROJECT_ACTIONS = {
   CHANGE_CATALOG_PAGE,
   GO_BACK_TO_CATALOG_PAGE,
   THROW_ERROR,
-  THROW_WARNING
+  THROW_WARNING,
+  COPY_PROPERTIES,
+  PASTE_PROPERTIES
 };
 
 export const VIEWER2D_ACTIONS = {
